@@ -169,7 +169,7 @@ lsm_p_ncore_calc <- function(landscape, directions, consider_boundary, edge_dept
                              points = NULL){
 
     # conver to matrix
-    if(class(landscape) != "matrix") {
+    if (!inherits(x = landscape, what = "matrix")) {
 
         # get coordinates and values of all cells
         points <- raster_to_points(landscape)[, 2:4]
@@ -178,6 +178,15 @@ lsm_p_ncore_calc <- function(landscape, directions, consider_boundary, edge_dept
         landscape <- raster::as.matrix(landscape)
     }
 
+    # all values NA
+    if (all(is.na(landscape))) {
+        return(tibble::tibble(level = "patch",
+                              class = as.integer(NA),
+                              id = as.integer(NA),
+                              metric = "ncore",
+                              value = as.double(NA)))
+    }
+
     # get unique classes
     classes <- get_unique_values(landscape)[[1]]
 
