@@ -2,11 +2,17 @@ context("construct_buffer")
 
 sample_points <- matrix(c(10, 5, 25, 15, 5, 25), ncol = 2, byrow = TRUE)
 points_sp <- sp::SpatialPoints(sample_points)
+points_spdf <- sp::SpatialPointsDataFrame(sample_points,
+                                          data = data.frame(id = 1:3))
 
 test_that("construct_buffer is typestable", {
 
-    expect_is(construct_buffer(sample_points, shape = "circle", size = 5), "SpatialPolygons")
-    expect_is(construct_buffer(points_sp, shape = "square", size = 5), "SpatialPolygons")
+    expect_is(construct_buffer(sample_points,
+                               shape = "circle", size = 5), "SpatialPolygons")
+    expect_is(construct_buffer(points_sp,
+                               shape = "square", size = 5), "SpatialPolygons")
+    expect_is(construct_buffer(points_spdf,
+                               shape = "square", size = 5), "SpatialPolygons")
 })
 
 test_that("construct_buffer can return a matrix", {
@@ -19,6 +25,9 @@ test_that("construct_buffer can return a matrix", {
                                shape = "circle", size = 5,
                                return_sp = FALSE), "matrix")
 
+    expect_is(construct_buffer(points_spdf,
+                               shape = "circle", size = 5,
+                               return_sp = FALSE), "matrix")
 })
 
 test_that("construct_buffer returns error for unkown shape", {
