@@ -10,19 +10,19 @@ patches_landscape_list <- show_patches(landscape_list, class = c(2,3))
 
 
 test_that("show_patches returns a plot", {
-    expect_equal(class(patches_landscape), c("gg","ggplot"))
+    expect_true(inherits(x = patches_landscape, what = c("gg","ggplot")))
 })
 
 test_that("show_patches returns a plot for each list entry", {
-    expect_true(all(vapply(patches_landscape_stack,
-                           FUN = function(x) class(x)[2],
-                           FUN.VALUE = character(1)) == "ggplot"))
-    expect_true(all(vapply(patches_landscape_brick,
-                           FUN = function(x) class(x)[2],
-                           FUN.VALUE = character(1)) == "ggplot"))
-    expect_true(all(vapply(patches_landscape_list,
-                           FUN = function(x) class(x)[2],
-                           FUN.VALUE = character(1)) == "ggplot"))
+
+    expect_true(all(vapply(patches_landscape_stack,  FUN = function(x)
+        inherits(x = x,  c("gg","ggplot")), FUN.VALUE = logical(1))))
+
+    expect_true(all(vapply(patches_landscape_brick,  FUN = function(x)
+        inherits(x = x,  c("gg","ggplot")), FUN.VALUE = logical(1))))
+
+    expect_true(all(vapply(patches_landscape_list,  FUN = function(x)
+        inherits(x = x,  c("gg","ggplot")), FUN.VALUE = logical(1))))
 })
 
 test_that("show_patches returns warnings and errors", {
